@@ -4,13 +4,11 @@ function(con, verbose, OK=NULL) {
 
   if(as.numeric(err[3]) %in% OK || as.numeric(err[3]) > 1000) {
     if(as.numeric(err[3]) == 1100) {
-      close(con)
-      #warning(paste(.twsERR[err[3],]))
+
+      #close(con)  # instead of closing connection, we'll 
       warning(err[4])
-      #error("Connectivity between IB and TWS has been lost. Connection has been closed.")
     }
     if(verbose > 1) {
-      #warning(paste(.twsERR[err[3],]))
       warning(err[4])
       return(TRUE)
     } else return(TRUE)
