@@ -1,8 +1,8 @@
 `twsFuture` <-
 function(symbol,exch,expiry,primary='',
-         currency='USD',right='',local='',multiplier='',include_expired='0')
+         currency='USD',right='',local='',multiplier='',include_expired='0',conId=0)
 {
-  twsContract(symbol,'FUT',exch,primary,expiry,strike='0.0',
+  twsContract(conId,symbol,'FUT',exch,primary,expiry,strike='0.0',
               currency,right,local,multiplier,NULL,NULL,include_expired)
 }
 
