@@ -5,8 +5,11 @@ function(x,...) {
 }
 
 print.twsconn <- function(x,...) {
+  if( isOpen(x[[1]])) {
   cat('<twsConnection,',x$clientId,' @ ',
       as.character(x$connected.at),', nextId=',x$nextValidId,'>\n', sep="")
+  } else
+  cat('<twsConnection, CLOSED>\n')
 }
 
 `[[.twsconn` <- function(x, i, ...) {
